@@ -1709,6 +1709,7 @@ bool BufferParams::writeLaTeX(otexstream & os, LaTeXFeatures & features,
 
 	// Now insert the LyX specific LaTeX commands...
 	docstring lyxpreamble;
+	features.resolveAlternatives();
 
 	if (output_sync) {
 		if (!output_sync_macro.empty())
@@ -2078,6 +2079,13 @@ bool BufferParams::isExportable(string const & format) const
 }
 
 
+namespace {
+bool formatSorter(Format const * lhs, Format const * rhs) {
+	return _(lhs->prettyname()) < _(rhs->prettyname());
+}
+}
+
+
 vector<Format const *> BufferParams::exportableFormats(bool only_viewable) const
 {
 	vector<string> const backs = backends();
@@ -2094,6 +2102,7 @@ vector<Format const *> BufferParams::exportableFormats(bool only_viewable) const
 			theConverters().getReachable(*it, only_viewable, false, excludes);
 		result.insert(result.end(), r.begin(), r.end());
 	}
+	sort(result.begin(), result.end(), formatSorter);
 	return result;
 }
 
@@ -2544,6 +2553,14 @@ string const BufferParams::dvips_options() const
 {
 	string result;
 
+	// If the class loads the geometry package, we do not know which
+	// paper size is used, since we do not set it (bug 7013).
+	// Therefore we must not specify any argument here.
+	// dvips gets the correct paper size via DVI specials in this case
+	// (if the class uses the geometry package correctly).
+	if (documentClass().provides("geometry"))
+		return result;
+
 	if (use_geometry
 	    && papersize == PAPER_CUSTOM
 	    && !lyxrc.print_paper_dimension_flag.empty()
