@@ -375,6 +375,17 @@ void SpellcheckerWidget::Private::check()
 	BufferView * bv = gv_->documentBufferView();
 	if (!bv || bv->buffer().text().empty())
 		return;
+	SpellChecker * speller = theSpellChecker();
+	if (speller && !speller->hasDictionary(bv->buffer().language())) {
+		int dsize = speller->numDictionaries();
+		if (0 == dsize) {
+			dv_->hide();
+			QMessageBox::information(p,
+				qt_("Spell Checker"),
+				qt_("Spell checker has no dictionaries."));
+			return;
+		}
+	}
 
 	DocIterator from = bv->cursor();
 	DocIterator to;
